@@ -36,7 +36,7 @@ import remote
 import local
 
 
-VERSION = '0.3.2'
+VERSION = '0.4.0'
 
 
 def hook_setup(cmd):
@@ -48,6 +48,24 @@ def hook_destroy(cmd):
     if '-h' in cmd: return
     local.confirm('Please confirm destruction')
 
+def hook_push(cmd):
+    if '-h' in cmd or len(cmd) < 2:
+        return
+    if len(cmd) == 2:
+        cmd.append('.')
+    orig = dir = os.path.realpath(cmd[2])
+    while True:
+        if os.path.isdir(dir) and os.path.exists(os.path.join(dir, 'dotcloud.yml')):
+            if dir != orig:
+                utils.info('# Found dotcloud.yml: Using {0} as a base directory'.format(dir))
+            cmd[2] = dir
+            return
+        prev = dir
+        dir = os.path.realpath(os.path.join(dir, os.path.pardir))
+        if dir == prev:
+            local.confirm('Could not find dotcloud.yml file in {0} and parent directories. Proceed?'.format(orig))
+            break
+
 def hook___version(cmd):
     print 'DotCloud CLI version {0}'.format(VERSION)
     sys.exit(0)
@@ -71,12 +89,6 @@ def hook___import(cmd):
         _import(sys.stdin)
     sys.exit(0)
 
-_trace = False
-def hook___trace(cmd):
-    global _trace
-    cmd.pop(0)
-    _trace = True
-
 def run_remote(cmd):
     r = remote.Remote()
     handlers = {
@@ -134,7 +146,7 @@ def run_loop(cmd, state, interval, timeout=100):
             break
         if count > timeout:
             sys.stderr.write('\nTimed out\n')
-            sys.exit(1)
+            break
         if isinstance(state, dict) and 'active' in state:
             count = 0
         else:
@@ -159,7 +171,6 @@ def run_command(cmd, internal=False, retval=False, progress=False):
         else:
             req = httplib.HTTPConnection(url['host'], int(url['port'] or 80))
         _request = req
-    original_cmd = cmd
     cmd = urllib.quote(json.dumps(cmd))
     query = '{0}run?{1}={2}'.format(url['path'] or '/', 'c' if internal is True else 'q', cmd)
     headers = sign_request(cfg.apikey, 'GET', query)
@@ -167,12 +178,10 @@ def run_command(cmd, internal=False, retval=False, progress=False):
         'User-Agent': 'dotcloud/cli (version: {0})'.format(VERSION),
         'X-DotCloud-Version': VERSION
         })
-    trace_id = None
     try:
         req.request('GET', query, headers=headers)
         resp = req.getresponse()
         info = resp.getheader('X-Dotcloud-Info')
-        trace_id = resp.getheader('X-Dotcloud-TraceID')
         data = resp.read()
         req.close()
         if _export is True:
@@ -180,9 +189,6 @@ def run_command(cmd, internal=False, retval=False, progress=False):
             return
         if info:
             utils.warning(info.replace(';', '\n'))
-        if _trace and trace_id:
-            utils.info('TraceID for "{0}": {1}'.format(
-                original_cmd, trace_id))
         data = json.loads(data)
         if data['type'] == 'cmd':
             return run_remote(data['data'])
@@ -193,19 +199,9 @@ def run_command(cmd, internal=False, retval=False, progress=False):
         elif progress:
             sys.stderr.write('.')
     except socket.error, e:
-        utils.die('Cannot reach DotCloud service ("{0}").\n' \
-                'Please check the connectivity and try again.'.format(str(e)))
+        utils.die('Cannot reach DotCloud service ("{0}").\nPlease check the connectivity and try again.'.format(str(e)))
     except Exception, e:
-        message = 'DotCloud service unavailable ("{0}").\n' \
-                'Data received:\n---\n{1}\n---\n' \
-                'Please try again later. ' \
-                'If the problem persists, send an email to support@dotcloud.com'.format(
-                    e, data)
-        if trace_id:
-            message += '\nand include the following TraceID: {0}'.format(trace_id)
-        else:
-            message += '.'
-        utils.die(message)
+        utils.die('DotCloud service unavailable ("{0}").\nData received:\n---\n{1}\n---\nPlease try again later. If the problem persists, send an email to support@dotcloud.com.'.format(e, data))
     finally:
         try:
             req.close()
