@@ -21,13 +21,16 @@
 import os
 import json
 
-from utils import die, info
+from utils import die, info, is_windows
 
 
 CONFIG_DIR = os.path.expanduser('~/.dotcloud')
 CONFIG_FILE = os.path.basename(os.environ.get('DOTCLOUD_CONFIG_FILE', 'dotcloud.conf'))
 CONFIG_PATH = os.path.join(CONFIG_DIR, CONFIG_FILE)
-CONFIG_KEY = os.path.join(CONFIG_DIR, 'dotcloud.key')
+if 'DOTCLOUD_CONFIG_FILE' in os.environ:
+    CONFIG_KEY = CONFIG_PATH + '.key'
+else:
+    CONFIG_KEY = os.path.join(CONFIG_DIR, 'dotcloud.key')
 
 
 class Config(dict):
@@ -78,7 +81,8 @@ def move_old_config():
         if 'DOTCLOUD_CONFIG_FILE' not in os.environ:
             data = data.replace('http://', 'https://')
         f.write(data)
-        os.fchmod(f.fileno(), 0600)
+        if not is_windows():
+            os.fchmod(f.fileno(), 0600)
     info('Migrated from {0}'.format(old_file))
     return True
 
@@ -95,4 +99,5 @@ def setup():
     conf['apikey'] = apikey
     with open(CONFIG_PATH, 'w') as f:
         json.dump(conf, f, indent=4)
-        os.fchmod(f.fileno(), 0600)
+        if not is_windows():
+            os.fchmod(f.fileno(), 0600)
