@@ -23,7 +23,7 @@ import subprocess
 
 import utils
 import config
-import local
+
 
 class Remote(object):
 
@@ -33,7 +33,6 @@ class Remote(object):
         self._ssh_options = (
                 'ssh', '-t',
                 '-i', config.CONFIG_KEY,
-                '-o', 'LogLevel=QUIET',
                 '-o', 'UserKnownHostsFile=/dev/null',
                 '-o', 'StrictHostKeyChecking=no',
                 '-o', 'PasswordAuthentication=no',
@@ -126,15 +125,13 @@ class Remote(object):
         ssh += ' -p {0}'.format(url['port'])
         if not os.path.isfile(local_dir) and not local_dir.endswith('/'):
             local_dir += '/'
-        ignore_file = os.path.join(local_dir, '.dotcloudignore')
-        ignore_opt = ('--exclude-from', ignore_file)
-        if not os.path.exists(ignore_file):
-            ignore_opt = tuple()
-        rsync = ('rsync', '-lpthrvz', '--delete', '--safe-links') + \
-                tuple('--exclude={0}'.format(e) for e in excludes) + ignore_opt + \
-                ('-e', ssh, local_dir,
-                        '{user}@{host}:{dest}/'.format(user=url['user'],
-                        host=url['host'], dest=url['path']))
+        rsync = (
+                    'rsync', '-lpthrvz', '--delete', '--safe-links',
+                ) + tuple('--exclude={0}'.format(e) for e in excludes) + (
+                    '-e', ssh, local_dir,
+                    '{user}@{host}:{dest}/'.format(user=url['user'],
+                        host=url['host'], dest=url['path'])
+                )
         try:
             ret = subprocess.call(rsync, close_fds=True)
             if ret != 0:
@@ -170,49 +167,10 @@ class Remote(object):
             except OSError:
                 self.die('git')
 
-    def upload_method(self, local_dir):
-        if os.path.isdir(os.path.join(local_dir, '.hg')):
-            return 'hg'
-        if os.path.isdir(os.path.join(local_dir, '.git')):
-            return 'git'
-        return 'rsync'
-
     def upload(self, local_dir, destination, args):
-        if args.get('check'):
-            local_dir = self.check_pushdir(local_dir)
-        if args.get('verify_key'):
-            self.verify_key(args.get('verify_key'))
         self.info('# upload {0} {1}'.format(local_dir, destination))
-        method = args.get('force_method') or self.upload_method(local_dir)
-        if method == 'hg':
+        if os.path.isdir(os.path.join(local_dir, '.hg')):
             return self.hg(local_dir, destination, args.get('hg', {}))
-        if method == 'git':
+        if os.path.isdir(os.path.join(local_dir, '.git')):
             return self.git(local_dir, destination, args.get('git', {}))
         return self.rsync(local_dir, destination, args.get('rsync', {}))
-
-    def verify_key(self, key):
-        f = open(config.CONFIG_KEY).read()
-        if not f.replace('\n', '') == key.replace('\n', ''):
-            utils.die('Error: you seem to have a stale key file "{0}"\n'
-                      'Remove the file or run "dotcloud setup" command again.'.format(config.CONFIG_KEY))
-
-    def check_pushdir(self, local_dir):
-        orig = dir = os.path.realpath(local_dir)
-        if ':' in orig: # win32?
-            return self.check_pushdir_win32(local_dir)
-        while True:
-            if os.path.isdir(dir) and os.path.exists(os.path.join(dir, 'dotcloud.yml')):
-                if dir != orig:
-                    utils.info('# Found dotcloud.yml: Using {0} as a base directory'.format(dir))
-                return dir
-            prev = dir
-            dir = os.path.realpath(os.path.join(dir, os.path.pardir))
-            if dir == prev:
-                local.confirm('Could not find dotcloud.yml file in {0} and parent directories. Proceed?'.format(orig))
-                break
-        return orig
-
-    def check_pushdir_win32(self, local_dir):
-        if not os.path.exists(os.path.join(local_dir, 'dotcloud.yml')):
-            local.confirm('Could not find dotcloud.yml file in {0}. Proceed?'.format(local_dir))
-        return local_dir
